@@ -1166,6 +1166,33 @@ def _create_espn_player_model(
         defensive_actions_outside_penalty_area=None,
         average_distance_of_defensive_actions=None,
         three_point_attempt_rate=None,
+        batting_style=None,
+        bowling_style=None,
+        playing_roles=None,
+        runs=None,
+        balls=None,
+        fours=None,
+        sixes=None,
+        strikerate=None,
+        fall_of_wicket_order=None,
+        fall_of_wicket_num=None,
+        fall_of_wicket_runs=None,
+        fall_of_wicket_balls=None,
+        fall_of_wicket_overs=None,
+        fall_of_wicket_over_number=None,
+        ball_over_actual=None,
+        ball_over_unique=None,
+        ball_total_runs=None,
+        ball_batsman_runs=None,
+        overs=None,
+        maidens=None,
+        conceded=None,
+        wickets=None,
+        economy=None,
+        runs_per_ball=None,
+        dots=None,
+        wides=None,
+        no_balls=None,
     )
 
 
