@@ -304,6 +304,20 @@ def _create_sportsreference_team_model(
             coaches=[],
             lbw=None,
             end_dt=None,
+            runs=None,
+            wickets=None,
+            overs=None,
+            balls=None,
+            byes=None,
+            leg_byes=None,
+            wides=None,
+            no_balls=None,
+            penalties=None,
+            balls_per_over=None,
+            fours=None,
+            sixes=None,
+            catches=None,
+            catches_dropped=None,
             version=version,
         )
 
@@ -328,6 +342,20 @@ def _create_sportsreference_team_model(
             coaches=[],
             lbw=None,
             end_dt=None,
+            runs=None,
+            wickets=None,
+            overs=None,
+            balls=None,
+            byes=None,
+            leg_byes=None,
+            wides=None,
+            no_balls=None,
+            penalties=None,
+            balls_per_over=None,
+            fours=None,
+            sixes=None,
+            catches=None,
+            catches_dropped=None,
             version=version,
         )
     response.raise_for_status()
@@ -598,6 +626,20 @@ def _create_sportsreference_team_model(
         else [],
         lbw=None,
         end_dt=None,
+        runs=None,
+        wickets=None,
+        overs=None,
+        balls=None,
+        byes=None,
+        leg_byes=None,
+        wides=None,
+        no_balls=None,
+        penalties=None,
+        balls_per_over=None,
+        fours=None,
+        sixes=None,
+        catches=None,
+        catches_dropped=None,
         version=version,
     )
 
