@@ -455,6 +455,33 @@ class TestCombinedTeamModel(unittest.TestCase):
                 defensive_actions_outside_penalty_area=None,
                 average_distance_of_defensive_actions=None,
                 three_point_attempt_rate=None,
+                batting_style=None,
+                bowling_style=None,
+                playing_roles=None,
+                runs=None,
+                balls=None,
+                fours=None,
+                sixes=None,
+                strikerate=None,
+                fall_of_wicket_order=None,
+                fall_of_wicket_num=None,
+                fall_of_wicket_runs=None,
+                fall_of_wicket_balls=None,
+                fall_of_wicket_overs=None,
+                fall_of_wicket_over_number=None,
+                ball_over_actual=None,
+                ball_over_unique=None,
+                ball_total_runs=None,
+                ball_batsman_runs=None,
+                overs=None,
+                maidens=None,
+                conceded=None,
+                wickets=None,
+                economy=None,
+                runs_per_ball=None,
+                dots=None,
+                wides=None,
+                no_balls=None,
             )]
             team_models = [TeamModel(
                 identifier="a",
@@ -469,6 +496,20 @@ class TestCombinedTeamModel(unittest.TestCase):
                 coaches=[],
                 lbw=None,
                 end_dt=None,
+                runs=None,
+                wickets=None,
+                overs=None,
+                balls=None,
+                byes=None,
+                leg_byes=None,
+                wides=None,
+                no_balls=None,
+                penalties=None,
+                balls_per_over=None,
+                fours=None,
+                sixes=None,
+                catches=None,
+                catches_dropped=None,
                 version=VERSION,
             )]
             team_model = create_combined_team_model(
@@ -911,6 +952,33 @@ class TestCombinedTeamModel(unittest.TestCase):
                 defensive_actions_outside_penalty_area=None,
                 average_distance_of_defensive_actions=None,
                 three_point_attempt_rate=None,
+                batting_style=None,
+                bowling_style=None,
+                playing_roles=None,
+                runs=None,
+                balls=None,
+                fours=None,
+                sixes=None,
+                strikerate=None,
+                fall_of_wicket_order=None,
+                fall_of_wicket_num=None,
+                fall_of_wicket_runs=None,
+                fall_of_wicket_balls=None,
+                fall_of_wicket_overs=None,
+                fall_of_wicket_over_number=None,
+                ball_over_actual=None,
+                ball_over_unique=None,
+                ball_total_runs=None,
+                ball_batsman_runs=None,
+                overs=None,
+                maidens=None,
+                conceded=None,
+                wickets=None,
+                economy=None,
+                runs_per_ball=None,
+                dots=None,
+                wides=None,
+                no_balls=None,
             )]
             team_models_2 = [TeamModel(
                 identifier="a",
@@ -925,6 +993,20 @@ class TestCombinedTeamModel(unittest.TestCase):
                 coaches=[],
                 lbw=None,
                 end_dt=None,
+                runs=None,
+                wickets=None,
+                overs=None,
+                balls=None,
+                byes=None,
+                leg_byes=None,
+                wides=None,
+                no_balls=None,
+                penalties=None,
+                balls_per_over=None,
+                fours=None,
+                sixes=None,
+                catches=None,
+                catches_dropped=None,
                 version=VERSION,
             )]
             team_model_2 = create_combined_team_model(
@@ -1376,6 +1458,33 @@ class TestCombinedTeamModel(unittest.TestCase):
                 defensive_actions_outside_penalty_area=None,
                 average_distance_of_defensive_actions=None,
                 three_point_attempt_rate=None,
+                batting_style=None,
+                bowling_style=None,
+                playing_roles=None,
+                runs=None,
+                balls=None,
+                fours=None,
+                sixes=None,
+                strikerate=None,
+                fall_of_wicket_order=None,
+                fall_of_wicket_num=None,
+                fall_of_wicket_runs=None,
+                fall_of_wicket_balls=None,
+                fall_of_wicket_overs=None,
+                fall_of_wicket_over_number=None,
+                ball_over_actual=None,
+                ball_over_unique=None,
+                ball_total_runs=None,
+                ball_batsman_runs=None,
+                overs=None,
+                maidens=None,
+                conceded=None,
+                wickets=None,
+                economy=None,
+                runs_per_ball=None,
+                dots=None,
+                wides=None,
+                no_balls=None,
             )]
             team_models = [TeamModel(
                 identifier="a",
@@ -1390,6 +1499,20 @@ class TestCombinedTeamModel(unittest.TestCase):
                 coaches=[],
                 lbw=None,
                 end_dt=None,
+                runs=None,
+                wickets=None,
+                overs=None,
+                balls=None,
+                byes=None,
+                leg_byes=None,
+                wides=None,
+                no_balls=None,
+                penalties=None,
+                balls_per_over=None,
+                fours=None,
+                sixes=None,
+                catches=None,
+                catches_dropped=None,
                 version=VERSION,
             )]
             team_model = create_combined_team_model(
@@ -1832,6 +1955,33 @@ class TestCombinedTeamModel(unittest.TestCase):
                 defensive_actions_outside_penalty_area=None,
                 average_distance_of_defensive_actions=None,
                 three_point_attempt_rate=None,
+                batting_style=None,
+                bowling_style=None,
+                playing_roles=None,
+                runs=None,
+                balls=None,
+                fours=None,
+                sixes=None,
+                strikerate=None,
+                fall_of_wicket_order=None,
+                fall_of_wicket_num=None,
+                fall_of_wicket_runs=None,
+                fall_of_wicket_balls=None,
+                fall_of_wicket_overs=None,
+                fall_of_wicket_over_number=None,
+                ball_over_actual=None,
+                ball_over_unique=None,
+                ball_total_runs=None,
+                ball_batsman_runs=None,
+                overs=None,
+                maidens=None,
+                conceded=None,
+                wickets=None,
+                economy=None,
+                runs_per_ball=None,
+                dots=None,
+                wides=None,
+                no_balls=None,
             )]
             team_models_2 = [TeamModel(
                 identifier="a",
@@ -1846,6 +1996,20 @@ class TestCombinedTeamModel(unittest.TestCase):
                 coaches=[],
                 lbw=None,
                 end_dt=None,
+                runs=None,
+                wickets=None,
+                overs=None,
+                balls=None,
+                byes=None,
+                leg_byes=None,
+                wides=None,
+                no_balls=None,
+                penalties=None,
+                balls_per_over=None,
+                fours=None,
+                sixes=None,
+                catches=None,
+                catches_dropped=None,
                 version=VERSION,
             )]
             team_model_2 = create_combined_team_model(
@@ -1886,6 +2050,20 @@ class TestCombinedTeamModel(unittest.TestCase):
             coaches=[coach_model],
             lbw=None,
             end_dt=None,
+            runs=None,
+            wickets=None,
+            overs=None,
+            balls=None,
+            byes=None,
+            leg_byes=None,
+            wides=None,
+            no_balls=None,
+            penalties=None,
+            balls_per_over=None,
+            fours=None,
+            sixes=None,
+            catches=None,
+            catches_dropped=None,
             version=VERSION,
         )]
         team_model = create_combined_team_model(
@@ -1911,6 +2089,20 @@ class TestCombinedTeamModel(unittest.TestCase):
             coaches=[],
             lbw=None,
             end_dt=None,
+            runs=None,
+            wickets=None,
+            overs=None,
+            balls=None,
+            byes=None,
+            leg_byes=None,
+            wides=None,
+            no_balls=None,
+            penalties=None,
+            balls_per_over=None,
+            fours=None,
+            sixes=None,
+            catches=None,
+            catches_dropped=None,
             version=VERSION,
         )]
         next_team_model = create_combined_team_model(
